@@ -140,7 +140,7 @@ def page_html_render(number_item, content, title, marker='XXX/TODO'):
         <title>%(marker)s Comment report%(pagetitle)s</title>
     </head>
     <body>
-        <h1>%(marker)s Comment report</h1>
+        <h1>%(marker)s Comment report%(pagetitle)s</h1>
 
 <p>Generated on %(reporttime)s</p>
 
